@@ -6,14 +6,19 @@ Xacobeo::Document - An XML document and it's related information.
 
 	use Xacobeo::Document;
 	
-	my $document Xacobeo::Document->new('file.xml');
+	my $document = Xacobeo::Document->new('file.xml');
 	
 	my $namespaces = $document->namespaces(); # Hashref
-	while (my ($prefix, $uri) = each %{ $namespaces }) {
+	while (my ($uri, $prefix) = each %{ $namespaces }) {
 		printf "%-5s: %s\n", $prefix, $uri;
 	}
 	
-	my @nodes = $document->findnodes('/x:html//x:a[@href]');
+	
+	my $nodes = $document->find('/x:html//x:a[@href]');
+	foreach my $node ($nodes->get_nodelist) {
+		print "Got node ", $node->name, "\n";
+	}
+	
 	$document->validate('/x:html//x:a[@href]') or die "Invalid XPath expression";
 
 =head1 DESCRIPTION
@@ -78,9 +83,11 @@ Runs the given XPath query on the document and returns the results. The results
 could be a node list or a single value like a boolean, a number or a scalar if
 an expression is passed.
 
+This method croaks if the expression can't be evaluated.
+
 Parameters:
 
-	$xpath: a valid XPath expression.
+	$xpath: the XPath expression to execute.
 
 =cut
 
@@ -93,7 +100,7 @@ sub find {
 		$result = $self->xpath->find($xpath, $self->xml);
 	};
 	if (my $error = $@) {
-		return;
+		croak $error;
 	}
 	
 	return $result;
@@ -106,9 +113,12 @@ Validates the syntax of the given XPath query. The syntax is validated within a
 context that has the same namespaces as the ones defined in the current XML
 document.
 
+B<NOTE>: This method can't validate if undefined functions or variables are
+used.
+
 Parameters:
 
-	$xpath: a valid XPath expression.
+	$xpath: the XPath expression to validate.
 
 =cut
 
@@ -138,8 +148,8 @@ sub validate {
 Returns the node name by prefixing it with our prefixes in the case where
 namespaces are used.
 
-
 =cut
+
 sub get_prefixed_name {
 	my $self = shift;
 	my ($node) = @_;
@@ -157,9 +167,13 @@ sub get_prefixed_name {
 
 
 
-#
-# Get/Set the namespaces.
-#
+=head2 namespaces
+
+Returns the namespaces declared in the document. The namespaces are returned in
+a hash REF where the URIs are used as a key and the prefix as a value.
+
+=cut
+
 sub namespaces {
 	my $self = shift;
 	if (@_) {
@@ -215,13 +229,19 @@ sub _construct_xml_parser {
 # Each prefix is warrantied to be unique. The function will assign the first
 # prefix seen for each namespace.
 #
+# NOTE: libxml2 assumes that the prefix 'xml' is is bounded to the URI
+#       http://www.w3.org/XML/1998/namespace, therefore this namespace will
+#       always be returned even if it's not declared in the document.
+#
 # The prefixes are returned in an hash ref of type ($uri => $prefix).
 #
 sub _get_all_namespaces {
 	my ($node) = @_;
 
 	# Find the namespaces ($uri -> $prefix)
-	my %namespaces = ();
+	my %namespaces = (
+		XML_XML_NS() => 'xml',
+	);
 	foreach my $namespace ($node->findnodes('.//namespace::*')) {
 		my $uri = $namespace->getData;
 		$namespaces{$uri} ||= $namespace->getLocalName;
